@@ -7,8 +7,8 @@ class PairwiseLoss(SimilarityLoss):
     """Base class for pairwise losses.
 
     Args:
-        distance_metric_name: Name of the function, that returns a distance between two
-            embeddings. The class SiameseDistanceMetric contains pre-defined metrics
+        distance_metric_name: Name of the function, that returns a distance between two embeddings.
+            :class:`~quaterion.loss.metrics.SiameseDistanceMetric` contains pre-defined metrics
             that can be used.
     """
 
